@@ -1,5 +1,5 @@
 package CPAN::Testers::API;
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 # ABSTRACT: REST API for CPAN Testers data
 
 #pod =head1 SYNOPSIS
@@ -83,6 +83,15 @@ sub startup ( $app ) {
         default => { }, # Allow living without config file
     } );
 
+    # Allow CORS for everyone
+    $app->hook( after_build_tx => sub {
+        my ( $tx, $app ) = @_;
+        $tx->res->headers->header( 'Access-Control-Allow-Origin' => '*' );
+        $tx->res->headers->header( 'Access-Control-Allow-Methods' => 'GET, POST, PUT, PATCH, DELETE, OPTIONS' );
+        $tx->res->headers->header( 'Access-Control-Max-Age' => 3600 );
+        $tx->res->headers->header( 'Access-Control-Allow-Headers' => 'Content-Type, X-Requested-With' );
+    } );
+
     my $r = $app->routes;
     $r->get( '/' => 'index' );
     $r->get( '/docs/*path' => { path => 'index.html' } )->to(
@@ -174,7 +183,7 @@ CPAN::Testers::API - REST API for CPAN Testers data
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
